@@ -27,34 +27,38 @@ describe 'basic watcher' do
         require              => Class['rabbitmq'],
       }
 
-      class { '::watcher::db::mysql':
-        password => 'a_big_secret',
-      }
-      class { '::watcher::db':
-        database_connection => 'mysql+pymysql://watcher:a_big_secret@127.0.0.1/watcher?charset=utf8',
-      }
-      class { '::watcher::keystone::auth':
-        password => 'a_big_secret',
-      }
-      class { '::watcher::keystone::authtoken':
-        password => 'a_big_secret',
-      }
-      class { '::watcher::logging':
-        debug => true,
-      }
-      class { '::watcher':
-        default_transport_url => 'rabbit://watcher:my_secret@127.0.0.1:5672/',
-      }
-      class { '::watcher::api':
-        watcher_client_password => 'a_big_secret',
-        create_db_schema  => true,
-        upgrade_db        => true,
-      }
-      class { '::watcher::applier':
-        applier_workers => '2',
-      }
-      class { '::watcher::decision_engine':
-        decision_engine_workers => '2',
+      # TODO(aschultz): fix after Ubuntu ocata-m3/rc1. watcher-db-manage is
+      # broken
+      if ($::osfamily == 'RedHat') {
+        class { '::watcher::db::mysql':
+          password => 'a_big_secret',
+        }
+        class { '::watcher::db':
+          database_connection => 'mysql+pymysql://watcher:a_big_secret@127.0.0.1/watcher?charset=utf8',
+        }
+        class { '::watcher::keystone::auth':
+          password => 'a_big_secret',
+        }
+        class { '::watcher::keystone::authtoken':
+          password => 'a_big_secret',
+        }
+        class { '::watcher::logging':
+          debug => true,
+        }
+        class { '::watcher':
+          default_transport_url => 'rabbit://watcher:my_secret@127.0.0.1:5672/',
+        }
+        class { '::watcher::api':
+          watcher_client_password => 'a_big_secret',
+          create_db_schema  => true,
+          upgrade_db        => true,
+        }
+        class { '::watcher::applier':
+          applier_workers => '2',
+        }
+        class { '::watcher::decision_engine':
+          decision_engine_workers => '2',
+        }
       }
       EOS
 
